// Taken from Tom Benedict's Orangutan-lib
// Modified by Ben Schmidel to work with the Orangutan LV-168

#ifndef _DEVICE_
#define _DEVICE_



/////////////////////////////////////////////////////////////////////
// Orangutan LV-168 pin assignments                                //
/////////////////////////////////////////////////////////////////////


#ifndef F_CPU
#define F_CPU 20000000UL
#endif //!F_CPU


// Serial Clock:

#define XCK0_DDR			DDRD
#define XCK0				PD4

// ADC:

#define ADC_DDR				DDRC
#define ADC_PORT			PORTC

// Onboard buzzer:

#define BUZZER_DDR			DDRB
#define BUZZER_PORT			PORTB
#define BUZZER_BIT			PB2

// Onboard LEDs:

#define LED_DDR				DDRD
#define LED_PORT			PORTD
#define LED0				PD1		// Red (on serial transmit line)
#define LED1				PD7 	// Green (on LCD data line DB7)

// Onboard Buttons:

#define BUTTON_DDR			DDRB
#define BUTTON_PORT			PORTB
#define BUTTON_PIN			PINB
#define BUTTON0				PB1
#define BUTTON1				PB4
#define BUTTON2				PB5

// LCD Pinouts:

// On the Orangutan LV-168, the LCD control lines are split between
// ports B and D:

#define LCD_RS_E_DDR		DDRD
#define LCD_RS_E_PORT		PORTD
#define LCD_RW_DDR			DDRB
#define LCD_RW_PORT			PORTB
#define LCD_RW				PB0
#define LCD_RS				PD2
#define LCD_E				PD4


// On the Orangutan the LCD's data lines are split between two
// ports, PORTB and PORTD.

#define LCD_PORTB_MASK		((1 << PB1) | (1 << PB4) | (1 << PB5))
#define LCD_PORTD_MASK		(1 << PD7)

// Since we're only using four data lines, and since the pins they're
// wired up to don't start with 0, we need to shift them into
// position in order to load their values into the LCD.  Port B uses
// bits 1, 4, and 5.  We need to make our data line up like this:
//
//	PortB:     7 6 5 4 3 2 1 0
//  LCD Data:      2 1     0
//
//  PortD:     7 6 5 4 3 2 1 0
//  LCD Data:  3
//
//  Pass your 4-bit LCD data value to the LCD_PORTB_DATA and LCD_PORTD_DATA
//  macros to get the respective PORTB and PORTD values.  You can use them
//  as follows:
//
//  PORTB &= ~LCD_PORTB_MASK;
//  PORTB |= LCD_PORTB_DATA(lcdData);
//  PORTD &= ~LCD_PORTD_MASK;
//  PORTD |= LCD_PORTD_DATA(lcdData);

#define LCD_PORTB_DATA(data)	(((data&0x01)<<1) | ((data&0x06)<<3))
#define LCD_PORTD_DATA(data)	((data&0x08)<<4)


// Data port bit where the LCD's busy flag lives

#define LCD_BF				7

// Size of the LCD (each starts at zero, so an 8x2 display would use
// the numbers 7 and 1.)

#define LCD_MAX_X			7
#define LCD_MAX_Y			1

// Motor Pinouts:

// Motor A:
#define IN1_DDR				DDRB
#define IN1_PORT			PORTB
#define IN1_BIT				PB1
#define IN2_DDR				DDRD
#define IN2_PORT			PORTD
#define IN2_BIT				PD5

// Motor B:
#define IN3_DDR				DDRB
#define IN3_PORT			PORTB
#define IN3_BIT				PB2
#define IN4_DDR				DDRD
#define IN4_PORT			PORTD
#define IN4_BIT				PD6


// Pin Change Interrupt Definitions:

#define PCI_PIN0	PINB
#define PCI_PIN1	PINC
#define PCI_PIN2	PIND
#define PCI_NUM		3

// SPI Definitions

#define SPI_DDR		DDRB
#define SPI_MISO	PB4
#define SPI_MOSI	PB3
#define SPI_SCK		PB5
#define SPI_SS		PB2

#define SPI_SPCR	SPCR
#define SPI_SPDR	SPDR
#define SPI_SPSR	SPSR
#define SPI_SPIF	SPIF
#define SPI_SPE		SPE
#define SPI_MSTR	MSTR
#define SPI_SPR0	SPR0

 
#endif //_DEVICE_
